@@ -24,10 +24,15 @@
 #include "dataoutputstream.h"
 #include "dbusauthobserver.h"
 #include "dbusconnection.h"
+#include "dbuserror.h"
+#include "dbusintrospection.h"
 #include "dbusmessage.h"
 #include "dbusmethodinvocation.h"
 #include "dbusownname.h"
+#include "dbusproxy.h"
 #include "dbusserver.h"
+#include "dbusutils.h"
+#include "dbuswatchname.h"
 #include "drive.h"
 #include "emblem.h"
 #include "emblemedicon.h"
@@ -60,6 +65,9 @@
 #include "networkaddress.h"
 #include "networkservice.h"
 #include "outputstream.h"
+#include "proxy.h"
+#include "proxyaddress.h"
+#include "proxyresolver.h"
 #include "resolver.h"
 #include "seekable.h"
 #include "settings.h"
@@ -102,6 +110,7 @@ GType g_dbus_auth_observer_get_type(void);
 GType g_dbus_connection_get_type(void);
 GType g_dbus_message_get_type(void);
 GType g_dbus_method_invocation_get_type(void);
+GType g_dbus_proxy_get_type(void);
 GType g_dbus_server_get_type(void);
 GType g_data_input_stream_get_type(void);
 GType g_data_output_stream_get_type(void);
@@ -130,6 +139,7 @@ GType g_mount_operation_get_type(void);
 GType g_network_address_get_type(void);
 GType g_network_service_get_type(void);
 GType g_output_stream_get_type(void);
+GType g_proxy_address_get_type(void);
 GType g_resolver_get_type(void);
 GType g_settings_get_type(void);
 GType g_socket_get_type(void);
@@ -176,6 +186,7 @@ namespace Gio {  class DBusAuthObserver_Class { public: static Glib::ObjectBase*
 namespace Gio {  class DBusConnection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class DBusMessage_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class DBusMethodInvocation_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class DBusProxy_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class DBusServer_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class DataInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class DataOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -204,6 +215,7 @@ namespace Gio {  class MountOperation_Class { public: static Glib::ObjectBase* w
 namespace Gio {  class NetworkAddress_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class NetworkService_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class OutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class ProxyAddress_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Resolver_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Settings_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Socket_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -250,6 +262,7 @@ void wrap_init()
   Glib::wrap_register(g_dbus_connection_get_type(), &Gio::DBusConnection_Class::wrap_new);
   Glib::wrap_register(g_dbus_message_get_type(), &Gio::DBusMessage_Class::wrap_new);
   Glib::wrap_register(g_dbus_method_invocation_get_type(), &Gio::DBusMethodInvocation_Class::wrap_new);
+  Glib::wrap_register(g_dbus_proxy_get_type(), &Gio::DBusProxy_Class::wrap_new);
   Glib::wrap_register(g_dbus_server_get_type(), &Gio::DBusServer_Class::wrap_new);
   Glib::wrap_register(g_data_input_stream_get_type(), &Gio::DataInputStream_Class::wrap_new);
   Glib::wrap_register(g_data_output_stream_get_type(), &Gio::DataOutputStream_Class::wrap_new);
@@ -278,6 +291,7 @@ void wrap_init()
   Glib::wrap_register(g_network_address_get_type(), &Gio::NetworkAddress_Class::wrap_new);
   Glib::wrap_register(g_network_service_get_type(), &Gio::NetworkService_Class::wrap_new);
   Glib::wrap_register(g_output_stream_get_type(), &Gio::OutputStream_Class::wrap_new);
+  Glib::wrap_register(g_proxy_address_get_type(), &Gio::ProxyAddress_Class::wrap_new);
   Glib::wrap_register(g_resolver_get_type(), &Gio::Resolver_Class::wrap_new);
   Glib::wrap_register(g_settings_get_type(), &Gio::Settings_Class::wrap_new);
   Glib::wrap_register(g_socket_get_type(), &Gio::Socket_Class::wrap_new);
@@ -316,6 +330,7 @@ void wrap_init()
   Gio::DBusConnection::get_type();
   Gio::DBusMessage::get_type();
   Gio::DBusMethodInvocation::get_type();
+  Gio::DBusProxy::get_type();
   Gio::DBusServer::get_type();
   Gio::DataInputStream::get_type();
   Gio::DataOutputStream::get_type();
@@ -344,6 +359,7 @@ void wrap_init()
   Gio::NetworkAddress::get_type();
   Gio::NetworkService::get_type();
   Gio::OutputStream::get_type();
+  Gio::ProxyAddress::get_type();
   Gio::Resolver::get_type();
   Gio::Settings::get_type();
   Gio::Socket::get_type();
