@@ -19,9 +19,14 @@
 
 #include "generate_extra_defs.h"
 #include <iostream>
+
+#define G_SETTINGS_ENABLE_BACKEND 1
 #include <gio/gio.h>
+#include <gio/gsettingsbackend.h>
 
 #ifndef G_OS_WIN32
+#include <gio/gunixcredentialsmessage.h>
+# include <gio/gunixfdmessage.h>
 # include <gio/gunixinputstream.h>
 # include <gio/gunixoutputstream.h>
 # include <gio/gunixconnection.h>
@@ -32,6 +37,7 @@ int main(int, char**)
   g_type_init ();
 
   std::cout << get_defs(G_TYPE_ASYNC_RESULT)
+            << get_defs(G_TYPE_APPLICATION)
             << get_defs(G_TYPE_CANCELLABLE)
             << get_defs(G_TYPE_BUFFERED_INPUT_STREAM)
             << get_defs(G_TYPE_BUFFERED_OUTPUT_STREAM)
@@ -52,6 +58,8 @@ int main(int, char**)
             << get_defs(G_TYPE_FILTER_OUTPUT_STREAM)
 
 #ifndef G_OS_WIN32
+            << get_defs(G_TYPE_UNIX_CREDENTIALS_MESSAGE)
+            << get_defs(G_TYPE_UNIX_FD_MESSAGE)
             << get_defs(G_TYPE_UNIX_INPUT_STREAM)
             << get_defs(G_TYPE_UNIX_OUTPUT_STREAM)
 #endif
@@ -62,7 +70,13 @@ int main(int, char**)
             << get_defs(G_TYPE_MEMORY_OUTPUT_STREAM)
             << get_defs(G_TYPE_MOUNT)
             << get_defs(G_TYPE_MOUNT_OPERATION)
+            << get_defs(G_TYPE_PROXY)
+            << get_defs(G_TYPE_PROXY_ADDRESS)
+            << get_defs(G_TYPE_PROXY_ADDRESS_ENUMERATOR)
+            << get_defs(G_TYPE_PROXY_RESOLVER)
             << get_defs(G_TYPE_SEEKABLE)
+            << get_defs(G_TYPE_SETTINGS)
+            << get_defs(G_TYPE_SETTINGS_BACKEND)
             << get_defs(G_TYPE_SIMPLE_ASYNC_RESULT)
             << get_defs(G_TYPE_THEMED_ICON)
 
@@ -73,6 +87,8 @@ int main(int, char**)
             << get_defs(G_TYPE_VOLUME_MONITOR)
 
             // network IO classes
+            << get_defs(G_TYPE_DBUS_AUTH_OBSERVER)
+            << get_defs(G_TYPE_DBUS_SERVER)
             << get_defs(G_TYPE_INET_ADDRESS)
             << get_defs(G_TYPE_INET_SOCKET_ADDRESS)
             << get_defs(G_TYPE_SOCKET_ADDRESS)
